@@ -47,7 +47,7 @@ class SearchRevisionTicketOp(hook.DataOperationMixIn,
                     continue
                 for eid in TICKET_EID_RGX.findall(' '.join(words[idx+1:])):
                     rset = self.session.execute(
-                        'Ticket X WHERE X eid %(x)s, T concerns P, '
+                        'Any X WHERE X eid %(x)s, T concerns P, '
                         'P source_repository R, R eid %(r)s',
                         {'x': typed_eid(eid), 'r': rev.repository.eid})
                     if rset:
@@ -76,8 +76,8 @@ class RevisionAdded(hook.Hook):
 
 class SetSourceRepositoryOp(hook.Operation):
     def precommit_event(self):
-        if not self.projet.source_repository and self.projectenv.repository:
-            self.projet.set_relations(source_repository=self.projectenv.repository)
+        if not self.project.source_repository and self.projectenv.repository:
+            self.project.set_relations(source_repository=self.projectenv.repository)
 
 class ApycotEnvironmentAdded(hook.Hook):
     __regid__ = 'trackervcs.revistion-to-ticket-state'
